@@ -25,18 +25,18 @@
 #include <libxml++/exceptions/exception.h>
 
 #include <exception>
-#include <string>
+#include <glibmm/ustring.h>
 
 namespace xmlpp {
   
 class internal_error: public exception
 {
 public:
-  explicit internal_error(const std::string& message);
-  virtual ~internal_error() throw();
+  explicit internal_error(const Glib::ustring& message);
+  ~internal_error() noexcept override;
 
-  virtual void Raise() const;
-  virtual exception * Clone() const;
+  void Raise() const override;
+  exception * Clone() const override;
 };
 
 } // namespace xmlpp
