@@ -23,24 +23,23 @@
 #define __LIBXMLPP_PARSE_ERROR_H
 
 #include <libxml++/exceptions/exception.h>
-#include <libxml++/api_export.h>
 
 #include <exception>
-#include <string>
+#include <glibmm/ustring.h>
 
 namespace xmlpp
 {
 
 /** This exception will be thrown when the parser encounters an error in the XML document.
  */  
-class LIBXMLPP_API parse_error: public exception
+class parse_error: public exception
 {
 public:
-  explicit parse_error(const std::string& message);
-  virtual ~parse_error() throw();
+  explicit parse_error(const Glib::ustring& message);
+  ~parse_error() noexcept override;
 
-  virtual void Raise() const;
-  virtual exception* Clone() const;
+  void Raise() const override;
+  exception* Clone() const override;
 };
 
 } // namespace xmlpp
